@@ -16,6 +16,6 @@ NULL
 utils::globalVariables(c(
   ".bin", ".is_val", "event_rate", "events", "lower",
   "predicted_midpoint", "total", "upper", ".config",
-  ".adj_estimate", ".rounded", '.pred', '.bound', 'pred_val', '.extracts',
+  ".adj_estimate", ".rounded", ".pred", ".bound", "pred_val", ".extracts",
   ".x", ".type", ".metrics"
 ))
