@@ -45,13 +45,16 @@ test_that("Logistic validation with data frame input", {
 
   pred_rs <- collect_predictions(val_with_pred)
   expect_equal(sort(unique(pred_rs$.type)), c("calibrated"))
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(pred_rs),
-    c("Class", ".row", ".config", ".pred_poor", ".pred_good", ".pred_class",
-      ".type")
+    c(
+      ".pred_class", ".pred_poor", ".pred_good", "Class", ".row", ".config",
+      ".type"
+    )
   )
   expect_equal(nrow(pred_rs), nrow(df$splits[[1]]$data))
-
 })
 
 
@@ -80,7 +83,6 @@ test_that("Beta validation with data frame input", {
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
     purrr::map_int(val_with_pred$.predictions_cal, nrow)
   )
-
 })
 
 
@@ -109,7 +111,6 @@ test_that("Isotonic validation classification with data frame input", {
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
     purrr::map_int(val_with_pred$.predictions_cal, nrow)
   )
-
 })
 
 test_that("Bootstrapped Isotonic classification validation with data frame input", {
@@ -137,7 +138,6 @@ test_that("Bootstrapped Isotonic classification validation with data frame input
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
     purrr::map_int(val_with_pred$.predictions_cal, nrow)
   )
-
 })
 
 test_that("Multinomial classification validation with data frame input", {
@@ -165,7 +165,6 @@ test_that("Multinomial classification validation with data frame input", {
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
     purrr::map_int(val_with_pred$.predictions_cal, nrow)
   )
-
 })
 
 # ------------------------------------------------------------------------------
@@ -222,7 +221,6 @@ test_that("Isotonic validation regression with data frame input", {
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
     purrr::map_int(val_with_pred$.predictions_cal, nrow)
   )
-
 })
 
 test_that("Bootstrapped Isotonic regression validation with data frame input", {
@@ -274,15 +272,16 @@ test_that("Logistic validation with `fit_resamples`", {
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred_class_1", ".pred_class_2",  ".pred_class")
+    c(".pred_class_1", ".pred_class_2", ".row", "outcome", ".config", ".pred_class")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
     purrr::map_int(val_with_pred$.predictions_cal, nrow)
   )
-
 })
 
 test_that("Isotonic classification validation with `fit_resamples`", {
@@ -305,9 +304,11 @@ test_that("Isotonic classification validation with `fit_resamples`", {
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred_class_1", ".pred_class_2",  ".pred_class")
+    c(".pred_class_1", ".pred_class_2", ".row", "outcome", ".config", ".pred_class")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
@@ -336,9 +337,11 @@ test_that("Bootstrapped isotonic classification validation with `fit_resamples`"
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred_class_1", ".pred_class_2",  ".pred_class")
+    c(".pred_class_1", ".pred_class_2", ".row", "outcome", ".config", ".pred_class")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
@@ -366,9 +369,11 @@ test_that("Beta calibration validation with `fit_resamples`", {
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred_class_1", ".pred_class_2",  ".pred_class")
+    c(".pred_class_1", ".pred_class_2", ".row", "outcome", ".config", ".pred_class")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
@@ -396,9 +401,11 @@ test_that("Multinomial calibration validation with `fit_resamples`", {
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred_one", ".pred_two", ".pred_three", ".pred_class")
+    c(".pred_one", ".pred_two", ".pred_three", ".row", "outcome", ".config", ".pred_class")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
@@ -430,9 +437,11 @@ test_that("Linear validation with `fit_resamples`", {
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred")
+    c(".pred", ".row", "outcome", ".config")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
@@ -460,20 +469,23 @@ test_that("Linear validation with `fit_resamples`", {
 
   pred <- collect_predictions(val_obj)
   expect_equal(sort(unique(pred$.type)), c("uncalibrated"))
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(pred),
-    c(".row", "outcome", ".config", ".pred", ".type")
+    c(".pred", ".row", "outcome", ".config", ".type")
   )
   expect_equal(nrow(pred), nrow(val_obj$splits[[1]]$data))
 
   pred_rs <- collect_predictions(val_with_pred)
   expect_equal(sort(unique(pred_rs$.type)), c("calibrated", "uncalibrated"))
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(pred_rs),
-    c(".row", "outcome", ".config", ".pred", ".type")
+    c(".pred", ".row", "outcome", ".config", ".type")
   )
   expect_equal(nrow(pred_rs), nrow(val_obj$splits[[1]]$data) * 2)
-
 })
 
 
@@ -498,9 +510,11 @@ test_that("Isotonic regression validation with `fit_resamples`", {
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred")
+    c(".pred", ".row", "outcome", ".config")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
@@ -532,9 +546,11 @@ test_that("Isotonic bootstrapped regression validation with `fit_resamples`", {
     names(val_with_pred),
     c("splits", "id", ".notes", ".predictions", ".metrics", ".metrics_cal", ".predictions_cal")
   )
+
+  skip_if_not_installed("tune", "1.2.0")
   expect_equal(
     names(val_with_pred$.predictions_cal[[1]]),
-    c(".row", "outcome", ".config", ".pred")
+    c(".pred", ".row", "outcome", ".config")
   )
   expect_equal(
     purrr::map_int(val_with_pred$splits, ~ holdout_length(.x)),
@@ -567,5 +583,3 @@ test_that("validation functions error with tune_results input", {
     cal_validate_multinomial(testthat_cal_binary())
   )
 })
-
-
